@@ -3,9 +3,11 @@ package DateTime::Locale::Base;
 use strict;
 use warnings;
 
+our $VERSION = '1.05';
+
 use Carp qw( carp );
 use DateTime::Locale;
-use List::MoreUtils ();
+use List::Util 1.45 ();
 use Params::Validate qw( validate_pos );
 
 BEGIN {
@@ -34,8 +36,8 @@ sub new {
     # key, it allows them to be settable.
     return bless {
         @_,
-        default_date_format_length => $class->_default_date_format_length(),
-        default_time_format_length => $class->_default_time_format_length(),
+        default_date_format_length => 'long',
+        default_time_format_length => 'long',
     }, $class;
 }
 
@@ -56,7 +58,7 @@ sub date_formats {
         map {
             my $meth = 'date_format_' . $_;
             $_ => $_[0]->$meth()
-            } @FormatLengths
+        } @FormatLengths
     };
 }
 
@@ -70,7 +72,7 @@ sub time_formats {
         map {
             my $meth = 'time_format_' . $_;
             $_ => $_[0]->$meth()
-            } @FormatLengths
+        } @FormatLengths
     };
 }
 
@@ -91,8 +93,7 @@ sub available_formats {
     # The various parens seem to be necessary to force uniq() to see
     # the caller's list context. Go figure.
     my @uniq
-        = List::MoreUtils::uniq(
-        map { keys %{ $_->_available_formats() || {} } }
+        = List::Util::uniq( map { keys %{ $_->_available_formats() || {} } }
             _self_and_super_path( ref $self ) );
 
     # Doing the sort in the same expression doesn't work under 5.6.x.
@@ -102,37 +103,37 @@ sub available_formats {
 # Copied wholesale from Class::ISA, because said module warns as deprecated
 # with perl 5.11.0+, which is kind of annoying.
 sub _self_and_super_path {
-  # Assumption: searching is depth-first.
-  # Assumption: '' (empty string) can't be a class package name.
-  # Note: 'UNIVERSAL' is not given any special treatment.
-  return () unless @_;
 
-  my @out = ();
+    # Assumption: searching is depth-first.
+    # Assumption: '' (empty string) can't be a class package name.
+    # Note: 'UNIVERSAL' is not given any special treatment.
+    return () unless @_;
 
-  my @in_stack = ($_[0]);
-  my %seen = ($_[0] => 1);
+    my @out = ();
 
-  my $current;
-  while(@in_stack) {
-    next unless defined($current = shift @in_stack) && length($current);
-    push @out, $current;
-    no strict 'refs';
-    unshift @in_stack,
-      map
-        { my $c = $_; # copy, to avoid being destructive
-          substr($c,0,2) = "main::" if substr($c,0,2) eq '::';
-           # Canonize the :: -> main::, ::foo -> main::foo thing.
-           # Should I ever canonize the Foo'Bar = Foo::Bar thing? 
-          $seen{$c}++ ? () : $c;
-        }
-        @{"$current\::ISA"}
-    ;
-    # I.e., if this class has any parents (at least, ones I've never seen
-    # before), push them, in order, onto the stack of classes I need to
-    # explore.
-  }
+    my @in_stack = ( $_[0] );
+    my %seen = ( $_[0] => 1 );
 
-  return @out;
+    my $current;
+    while (@in_stack) {
+        next unless defined( $current = shift @in_stack ) && length($current);
+        push @out, $current;
+        no strict 'refs';
+        unshift @in_stack, map {
+            my $c = $_;    # copy, to avoid being destructive
+            substr( $c, 0, 2 ) = "main::" if substr( $c, 0, 2 ) eq '::';
+
+            # Canonize the :: -> main::, ::foo -> main::foo thing.
+            # Should I ever canonize the Foo'Bar = Foo::Bar thing?
+            $seen{$c}++ ? () : $c;
+        } @{"$current\::ISA"};
+
+        # I.e., if this class has any parents (at least, ones I've never seen
+        # before), push them, in order, onto the stack of classes I need to
+        # explore.
+    }
+
+    return @out;
 }
 
 # Just needed for the above method.
@@ -471,16 +472,32 @@ sub STORABLE_thaw {
 
 1;
 
+# ABSTRACT: Base class for individual locale objects
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Locale::Base - Base class for individual locale objects
 
+=head1 VERSION
+
+version 1.05
+
 =head1 SYNOPSIS
 
   use base 'DateTime::Locale::Base';
 
+=head1 DESCRIPTION
+
+B<This module is no longer used by the code in the distribution.> It is still
+included for the sake of any code out in the wild that may subclass this
+class. This class will be removed in a future release.
+
 =head1 DEFAULT FORMATS
 
 Each locale has a set of four default date and time formats.  They are
@@ -781,22 +798,23 @@ one exists.
 
 See L<DateTime::Locale>.
 
-=head1 AUTHORS
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Locale>
+(or L<bug-datetime-locale@rt.cpan.org|mailto:bug-datetime-locale@rt.cpan.org>).
 
-Richard Evans <rich@ridas.com>
+There is a mailing list available for users of this distribution,
+L<mailto:datetime@perl.org>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
+=head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2003 Richard Evans. Copyright (c) 2004-2005 David
-Rolsky. All rights reserved. This program is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
+This software is copyright (c) 2016 by Dave Rolsky.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-The full text of the license can be found in the LICENSE file included
-with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
